## Python X3D Package x3d.py

Designers: Loren Peitso, John Carlson, Masaki Aono, and Don Brutzman

This project is used for creating and deploying x3d.py package for Python via PyPi.

* https://pypi.org/project/x3d ([tutorial](https://packaging.python.org/tutorials/packaging-projects))
* The non-profit [Web3D Consortium](https://www.web3D.org) maintains and releases this package under a BSD-style [open-source license](https://www.web3d.org/x3d/content/license.html)

Python installation options

* *pip install x3d*
* *python -m pip install x3d*

Notes

* The [X3D Unified Object Model (X3DUOM)](http://www.web3d.org/specifications/X3DUOM.html) is a full set of object-oriented interfaces for all nodes, fields and statements in the X3D Architecture Specification.

* Consistent [support for X3D Specifications](http://www.web3d.org/specifications/X3dSpecificationRelationships.png)
includes multiple file formats (XML, JSON, ClassicVRML, binary) and programming languages (JavaScript, Java, Python, C, C#, C++).

* The x3d.py package is autogenerated from X3DUOM via stylesheet
    http://www.web3d.org/x3d/stylesheets/X3duomToX3dPythonPackage.xslt

* Online package location is in x3d stylesheets subdirectory *python* (at same level as subdirectory *java* for [X3DJSAIL](http://www.web3d.org/specifications/java/X3DJSAIL.html))
    http://www.web3d.org/x3d/stylesheets/python
    http://www.web3d.org/x3d/stylesheets/python/x3d.py

* Ant build targets: *BuildX3dPythonPackageFromX3duom.saxon*, *test.X3dToPython.xslt.one*
    http://www.web3d.org/x3d/stylesheets/build.xml
    
* Version control:
    https://sourceforge.net/p/x3d/code/HEAD/tree/www.web3d.org/x3d/stylesheets
    https://sourceforge.net/p/x3d/code/HEAD/tree/www.web3d.org/x3d/stylesheets/build.xml
    https://sourceforge.net/p/x3d/code/HEAD/tree/www.web3d.org/x3d/stylesheets/X3duomToX3dPythonPackage.xslt
    https://sourceforge.net/p/x3d/code/HEAD/tree/www.web3d.org/x3d/stylesheets/X3dToPython.xslt (converter)
    https://sourceforge.net/p/x3d/code/HEAD/tree/www.web3d.org/x3d/stylesheets/python/README.md (this file)
    https://sourceforge.net/p/x3d/code/HEAD/tree/www.web3d.org/x3d/stylesheets/python/x3d.py (python package)

* X3D stylesheet descriptions are included in the X3D Resources, online at
    http://www.web3d.org/x3d/content/examples/X3dResources.html#Stylesheets

Discussion

* Mail list: [x3d-public@web3D.org](mailto:x3d-public@web3D.org?subject=Python%20X3D%20Package%20inquiry) ([subscribe](http://www.web3d.org/mailman/listinfo/x3d-public_web3d.org))
* Contact: [Don Brutzman and Loren Peitso, NPS](mailto:brutzman@nps.edu(Don%20Brutzman),lepeitso@nps.edu(Loren%20Peitso)?subject=Python%20X3D%20Package%20inquiry), package maintainers
